@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -30,11 +30,10 @@ import com.ait.lienzo.client.core.event.NodeMouseDoubleClickHandler;
 import com.ait.lienzo.client.core.shape.Layer;
 import com.google.gwt.user.client.Command;
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import org.drools.workbench.models.datamodel.oracle.DataType;
-import org.drools.workbench.models.datamodel.oracle.DropDownData;
+import org.drools.verifier.api.reporting.Issue;
+import org.drools.verifier.api.reporting.Severity;
 import org.drools.workbench.models.datamodel.rule.ActionFieldValue;
 import org.drools.workbench.models.datamodel.rule.ActionInsertFact;
-import org.drools.workbench.models.datamodel.rule.FactPattern;
 import org.drools.workbench.models.datamodel.rule.FieldNatureType;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionInsertFactCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.AttributeCol52;
@@ -44,25 +43,30 @@ import org.drools.workbench.models.guided.dtable.shared.model.BRLConditionColumn
 import org.drools.workbench.models.guided.dtable.shared.model.BaseColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.ConditionCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
+import org.drools.workbench.models.guided.dtable.shared.model.MetadataCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.Pattern52;
-import org.drools.workbench.screens.guided.dtable.client.widget.analysis.panel.IssueSelectedEvent;
+import org.drools.workbench.screens.guided.dtable.client.editor.search.GuidedDecisionTableSearchableElement;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableColumnSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectionsChangedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshActionsPanelEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshAttributesPanelEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshConditionsPanelEvent;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshMenusEvent;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshMetaDataPanelEvent;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoException;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.utilities.DependentEnumsUtilities;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableLinkManager.LinkFoundCallback;
-import org.drools.workbench.screens.guided.rule.client.editor.RuleAttributeWidget;
-import org.drools.workbench.services.verifier.api.client.reporting.Issue;
-import org.drools.workbench.services.verifier.api.client.reporting.Severity;
+import org.drools.workbench.screens.guided.rule.client.widget.attribute.RuleAttributeWidget;
 import org.jboss.errai.security.shared.api.identity.User;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.soup.project.datamodel.oracle.DataType;
+import org.kie.soup.project.datamodel.oracle.DropDownData;
 import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleBaselinePayload;
+import org.kie.workbench.common.services.verifier.reporting.client.panel.IssueSelectedEvent;
+import org.kie.workbench.common.widgets.client.search.common.SearchPerformedEvent;
 import org.kie.workbench.common.workbench.client.authz.WorkbenchFeatures;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
@@ -81,8 +85,23 @@ import org.uberfire.mvp.PlaceRequest;
 import static org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTablePresenter.Access.LockedBy.CURRENT_USER;
 import static org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTablePresenter.Access.LockedBy.NOBODY;
 import static org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTablePresenter.Access.LockedBy.OTHER_USER;
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyInt;
+import static org.mockito.Mockito.atLeast;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.reset;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePresenterTest {
@@ -135,10 +154,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
         dtPresenter.onUpdatedLockStatusEvent(event);
 
-        verify(modellerPresenter,
-               times(1)).onLockStatusUpdated(eq(dtPresenter));
-        assertEquals(CURRENT_USER,
-                     dtPresenter.getAccess().getLock());
+        verify(dtPresenter).refreshColumnsPage();
+        verify(dtPresenter).refreshMenus();
+        assertEquals(CURRENT_USER, dtPresenter.getAccess().getLock());
     }
 
     @Test
@@ -150,10 +168,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
 
         dtPresenter.onUpdatedLockStatusEvent(event);
 
-        verify(modellerPresenter,
-               times(1)).onLockStatusUpdated(eq(dtPresenter));
-        assertEquals(OTHER_USER,
-                     dtPresenter.getAccess().getLock());
+        verify(dtPresenter).refreshColumnsPage();
+        verify(dtPresenter).refreshMenus();
+        assertEquals(OTHER_USER, dtPresenter.getAccess().getLock());
     }
 
     @Test
@@ -162,10 +179,9 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         when(event.getFile()).thenReturn(dtPath);
         dtPresenter.onUpdatedLockStatusEvent(event);
 
-        verify(modellerPresenter,
-               times(1)).onLockStatusUpdated(eq(dtPresenter));
-        assertEquals(NOBODY,
-                     dtPresenter.getAccess().getLock());
+        verify(dtPresenter).refreshColumnsPage();
+        verify(dtPresenter).refreshMenus();
+        assertEquals(NOBODY, dtPresenter.getAccess().getLock());
     }
 
     @Test
@@ -800,6 +816,15 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         assertTrue(dtPresenter.hasColumnDefinitions());
     }
 
+    @Test
+    public void hasColumnDefinitionsWithMetadataColumn() {
+        final MetadataCol52 metadataCol52 = new MetadataCol52();
+
+        dtPresenter.getModel().getMetadataCols().add(metadataCol52);
+
+        assertTrue(dtPresenter.hasColumnDefinitions());
+    }
+
     @Test
     public void hasColumnDefinitionsWithActionColumn() {
         final ActionInsertFactCol52 action = new ActionInsertFactCol52();
@@ -872,87 +897,6 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         assertTrue(bindings.contains("$fact1"));
     }
 
-    @Test
-    public void canConditionBeDeletedWithSingleChildColumnWithAction() {
-        final Pattern52 pattern = new Pattern52();
-        pattern.setFactType("FactType1");
-        pattern.setBoundName("$fact");
-        final ConditionCol52 condition1 = new ConditionCol52();
-        condition1.setFactField("field1");
-        pattern.getChildColumns().add(condition1);
-
-        dtPresenter.getModel().getConditions().add(pattern);
-
-        final ActionInsertFactCol52 action = new ActionInsertFactCol52();
-        action.setFactType("FactType1");
-        action.setBoundName("$fact");
-        action.setFactField("field");
-
-        dtPresenter.getModel().getActionCols().add(action);
-
-        assertFalse(dtPresenter.canConditionBeDeleted(condition1));
-    }
-
-    @Test
-    public void canConditionBeDeletedWithSingleChildColumnWithNoAction() {
-        final Pattern52 pattern = new Pattern52();
-        pattern.setFactType("FactType1");
-        final ConditionCol52 condition1 = new ConditionCol52();
-        condition1.setFactField("field1");
-        pattern.getChildColumns().add(condition1);
-
-        dtPresenter.getModel().getConditions().add(pattern);
-
-        assertTrue(dtPresenter.canConditionBeDeleted(condition1));
-    }
-
-    @Test
-    public void canConditionBeDeletedWithMultipleChildColumns() {
-        final Pattern52 pattern = new Pattern52();
-        pattern.setFactType("FactType1");
-        final ConditionCol52 condition1 = new ConditionCol52();
-        condition1.setFactField("field1");
-        pattern.getChildColumns().add(condition1);
-        final ConditionCol52 condition2 = new ConditionCol52();
-        condition2.setFactField("field2");
-        pattern.getChildColumns().add(condition2);
-
-        dtPresenter.getModel().getConditions().add(pattern);
-
-        assertTrue(dtPresenter.canConditionBeDeleted(condition1));
-    }
-
-    @Test
-    public void canBRLFragmentConditionBeDeletedWithAction() {
-        final FactPattern fp = new FactPattern("FactType1");
-        fp.setBoundName("$fact");
-        final BRLConditionColumn column = new BRLConditionColumn();
-        column.getDefinition().add(fp);
-
-        dtPresenter.getModel().getConditions().add(column);
-
-        final ActionInsertFactCol52 action = new ActionInsertFactCol52();
-        action.setFactType("FactType1");
-        action.setBoundName("$fact");
-        action.setFactField("field");
-
-        dtPresenter.getModel().getActionCols().add(action);
-
-        assertFalse(dtPresenter.canConditionBeDeleted(column));
-    }
-
-    @Test
-    public void canBRLFragmentConditionBeDeletedWithNoAction() {
-        final FactPattern fp = new FactPattern("FactType1");
-        fp.setBoundName("$fact");
-        final BRLConditionColumn column = new BRLConditionColumn();
-        column.getDefinition().add(fp);
-
-        dtPresenter.getModel().getConditions().add(column);
-
-        assertTrue(dtPresenter.canConditionBeDeleted(column));
-    }
-
     @Test
     public void getValueListLookups() {
         final AttributeCol52 attribute = new AttributeCol52();
@@ -1079,7 +1023,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void appendPatternAndConditionColumn() throws ModelSynchronizer.MoveColumnVetoException {
+    public void appendPatternAndConditionColumn() throws VetoException {
         reset(modellerPresenter);
 
         final Pattern52 pattern = new Pattern52();
@@ -1101,7 +1045,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void appendConditionColumn() throws ModelSynchronizer.MoveColumnVetoException {
+    public void appendConditionColumn() throws VetoException {
         reset(modellerPresenter);
 
         final ConditionCol52 condition = new ConditionCol52();
@@ -1119,7 +1063,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void appendActionColumn() throws ModelSynchronizer.MoveColumnVetoException {
+    public void appendActionColumn() throws VetoException {
         reset(modellerPresenter);
 
         final ActionInsertFactCol52 action = new ActionInsertFactCol52();
@@ -1140,7 +1084,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void appendRow() throws ModelSynchronizer.MoveColumnVetoException {
+    public void appendRow() throws VetoException {
         reset(synchronizer,
               modellerPresenter);
 
@@ -1153,7 +1097,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void deleteConditionColumn() throws ModelSynchronizer.MoveColumnVetoException {
+    public void deleteConditionColumn() throws VetoException {
         final Pattern52 pattern = new Pattern52();
         pattern.setFactType("FactType");
         final ConditionCol52 condition = new ConditionCol52();
@@ -1173,7 +1117,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void deleteActionColumn() throws ModelSynchronizer.MoveColumnVetoException {
+    public void deleteActionColumn() throws VetoException {
         final ActionInsertFactCol52 column = new ActionInsertFactCol52();
         column.setFactType("FactType");
         column.setFactField("field");
@@ -1212,7 +1156,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void updatePatternAndConditionColumn() throws ModelSynchronizer.MoveColumnVetoException {
+    public void updatePatternAndConditionColumn() throws VetoException {
         final Pattern52 pattern = new Pattern52();
         pattern.setFactType("FactType");
         pattern.setBoundName("$f");
@@ -1245,7 +1189,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void updateConditionColumn() throws ModelSynchronizer.MoveColumnVetoException {
+    public void updateConditionColumn() throws VetoException {
         final Pattern52 pattern = new Pattern52();
         pattern.setFactType("FactType");
         final ConditionCol52 condition = new ConditionCol52();
@@ -1270,7 +1214,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void updateActionColumn() throws ModelSynchronizer.MoveColumnVetoException {
+    public void updateActionColumn() throws VetoException {
         final ActionInsertFactCol52 column = new ActionInsertFactCol52();
         column.setFactType("FactType");
         column.setFactField("field");
@@ -1464,7 +1408,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onDeleteSelectedColumnsWithSelections() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onDeleteSelectedColumnsWithSelections() throws VetoException {
         final AttributeCol52 column = new AttributeCol52() {
 
             {
@@ -1484,7 +1428,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onDeleteSelectedColumnsWithoutSelections() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onDeleteSelectedColumnsWithoutSelections() throws VetoException {
         dtPresenter.onDeleteSelectedColumns();
 
         verify(synchronizer,
@@ -1492,7 +1436,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onDeleteSelectedRowsWithSelections() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onDeleteSelectedRowsWithSelections() throws VetoException {
         final GridData uiModel = dtPresenter.getUiModel();
         uiModel.selectCell(0,
                            0);
@@ -1510,7 +1454,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onDeleteSelectedRowsWithNoSelections() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onDeleteSelectedRowsWithNoSelections() throws VetoException {
         dtPresenter.onDeleteSelectedRows();
 
         verify(synchronizer,
@@ -1518,7 +1462,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onInsertRowAboveNoRowSelected() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onInsertRowAboveNoRowSelected() throws VetoException {
         dtPresenter.onInsertRowAbove();
 
         verify(synchronizer,
@@ -1526,7 +1470,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onInsertRowAboveSingleRowSelected() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onInsertRowAboveSingleRowSelected() throws VetoException {
         final GridData uiModel = dtPresenter.getUiModel();
         uiModel.selectCell(0,
                            0);
@@ -1538,7 +1482,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onInsertRowAboveMultipleRowsSelected() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onInsertRowAboveMultipleRowsSelected() throws VetoException {
         final GridData uiModel = dtPresenter.getUiModel();
         uiModel.selectCell(0,
                            0);
@@ -1552,7 +1496,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onInsertRowBelowNoRowSelected() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onInsertRowBelowNoRowSelected() throws VetoException {
         dtPresenter.onInsertRowBelow();
 
         verify(synchronizer,
@@ -1560,7 +1504,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onInsertRowBelowSingleRowSelected() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onInsertRowBelowSingleRowSelected() throws VetoException {
         final GridData uiModel = dtPresenter.getUiModel();
         uiModel.selectCell(0,
                            0);
@@ -1572,7 +1516,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onInsertRowBelowMultipleRowsSelected() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onInsertRowBelowMultipleRowsSelected() throws VetoException {
         final GridData uiModel = dtPresenter.getUiModel();
         uiModel.selectCell(0,
                            0);
@@ -1586,7 +1530,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onOtherwiseCellNoCellSelected() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onOtherwiseCellNoCellSelected() throws VetoException {
         dtPresenter.onOtherwiseCell();
 
         verify(synchronizer,
@@ -1595,7 +1539,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onOtherwiseCellSingleCellSelected() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onOtherwiseCellSingleCellSelected() throws VetoException {
         final GridData uiModel = dtPresenter.getUiModel();
         uiModel.selectCell(0,
                            0);
@@ -1608,7 +1552,7 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void onOtherwiseCellMultipleCellsSelected() throws ModelSynchronizer.MoveColumnVetoException {
+    public void onOtherwiseCellMultipleCellsSelected() throws VetoException {
         final GridData uiModel = dtPresenter.getUiModel();
         uiModel.selectCell(0,
                            0);
@@ -1688,17 +1632,23 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
     }
 
     @Test
-    public void testInitialiseAccess() {
+    public void testInitialiseAccessReadOnlyTableWithEditableColumns() {
+        testInitialiseAccess(true, true);
+    }
 
-        final GuidedDecisionTablePresenter.Access access = mock(GuidedDecisionTablePresenter.Access.class);
+    @Test
+    public void testInitialiseAccessReadOnlyTableWithoutEditableColumns() {
+        testInitialiseAccess(true, false);
+    }
 
-        doReturn(access).when(dtPresenter).getAccess();
-        doReturn(true).when(dtPresenter).canEditColumns();
+    @Test
+    public void testInitialiseAccessEditableTableWithEditableColumns() {
+        testInitialiseAccess(false, true);
+    }
 
-        dtPresenter.initialiseAccess(true);
-
-        verify(access).setReadOnly(true);
-        verify(access).setHasEditableColumns(true);
+    @Test
+    public void testInitialiseAccessEditableTableWithoutEditableColumns() {
+        testInitialiseAccess(false, false);
     }
 
     @Test
@@ -1725,6 +1675,51 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
         final boolean hasEditableColumns = dtPresenter.hasEditableColumns();
 
         assertTrue(hasEditableColumns);
+        verify(access).hasEditableColumns();
+    }
+
+    @Test
+    public void testRefreshColumnsPage() {
+        dtPresenter.refreshColumnsPage();
+
+        verify(refreshAttributesPanelEvent).fire(any(RefreshAttributesPanelEvent.class));
+        verify(refreshMetaDataPanelEvent).fire(any(RefreshMetaDataPanelEvent.class));
+        verify(refreshConditionsPanelEvent).fire(any(RefreshConditionsPanelEvent.class));
+        verify(refreshActionsPanelEvent).fire(any(RefreshActionsPanelEvent.class));
+    }
+
+    @Test
+    public void testRefreshMenus() {
+        dtPresenter.refreshMenus();
+
+        verify(refreshMenusEvent).fire(any(RefreshMenusEvent.class));
+    }
+
+    @Test
+    public void testOnSearchPerformed() {
+        final GuidedDecisionTableSearchableElement element = mock(GuidedDecisionTableSearchableElement.class);
+        when(element.getModel()).thenReturn(model);
+        final SearchPerformedEvent event = new SearchPerformedEvent(element);
+
+        dtPresenter.onSearchPerformed(event);
+
+        verify(renderer, never()).clearCellHighlight();
+        verify(view).draw();
+    }
+
+    @Test
+    public void testOnSearchPerformedModelNotFromThisTable() {
+        // This test is for GDT Graphs
+        final GuidedDecisionTableSearchableElement element = mock(GuidedDecisionTableSearchableElement.class);
+        final GuidedDecisionTable52 anotherModel = mock(GuidedDecisionTable52.class);
+        when(element.getModel()).thenReturn(anotherModel);
+        when(element.getColumn()).thenReturn(0);
+        when(element.getRow()).thenReturn(0);
+        final SearchPerformedEvent event = new SearchPerformedEvent(element);
+
+        dtPresenter.onSearchPerformed(event);
+
+        verify(renderer).clearCellHighlight();
     }
 
     /*
@@ -1745,4 +1740,16 @@ public class GuidedDecisionTablePresenterTest extends BaseGuidedDecisionTablePre
                                                                                                                             p,
                                                                                                                             dtPresenter));
     }
+
+    private void testInitialiseAccess(final boolean readOnly, final boolean canEditColumns) {
+        final GuidedDecisionTablePresenter.Access access = mock(GuidedDecisionTablePresenter.Access.class);
+
+        doReturn(access).when(dtPresenter).getAccess();
+        doReturn(canEditColumns).when(dtPresenter).canEditColumns();
+
+        dtPresenter.initialiseAccess(readOnly);
+
+        verify(access).setReadOnly(readOnly);
+        verify(access).setHasEditableColumns(canEditColumns);
+    }
 }
