@@ -23,6 +23,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Optional;
+import java.util.OptionalDouble;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.function.Supplier;
@@ -268,6 +269,18 @@ public class ScenarioGridModel extends BaseGridData {
         simulation.removeFactMappingByIndex(columnIndex);
     }
 
+    /**
+     * This method <i>delete</i> the <b>whole instance</b> of the column at the given index from both the grid <b>and</b> the underlying model
+     * @param columnIndex
+     */
+    public void deleteInstance(int columnIndex) {
+        checkSimulation();
+        Range instanceRange = getInstanceLimits(columnIndex);
+        IntStream.iterate(instanceRange.getMaxRowIndex(), i -> i - 1)
+                .limit(instanceRange.getMaxRowIndex() - instanceRange.getMinRowIndex() + 1L)
+                .forEach(this::deleteColumn);
+    }
+
     /**
      * This method update the instance mapped inside a given column
      * @param columnIndex
@@ -318,6 +331,7 @@ public class ScenarioGridModel extends BaseGridData {
         String columnId = ((ScenarioGridColumn) column).getInformationHeaderMetaData().getColumnId();
         ExpressionIdentifier ei = ExpressionIdentifier.create(columnId, FactMappingType.valueOf(group));
         commonAddColumn(columnIndex, column, ei);
+        /* Restoring the expected columns dimension, overriding the automatic resizing */
         IntStream.range(0, widthsToRestore.size())
                 .forEach(index -> getColumns().get(index).setWidth(widthsToRestore.get(index)));
     }
@@ -406,11 +420,10 @@ public class ScenarioGridModel extends BaseGridData {
      * This methods returns the <code>List&lt;ScenarioGridColumn&gt;</code> of a <b>single</b> block of columns of the same instance/data object.
      * A <code>single</code> block contains the selected column and all the columns immediately to the left and right of it with the same "label".
      * If there is another column with the same "label" but separated by a different column, it is not part of the group.
-     * @param selectedColumn
+     * @param columnIndex
      * @return
      */
-    public List<ScenarioGridColumn> getInstanceScenarioGridColumns(ScenarioGridColumn selectedColumn) {
-        int columnIndex = columns.indexOf(selectedColumn);
+    public List<ScenarioGridColumn> getInstanceScenarioGridColumns(int columnIndex) {
         Range instanceRange = getInstanceLimits(columnIndex);
         return columns.subList(instanceRange.getMinRowIndex(), instanceRange.getMaxRowIndex() + 1)
                 .stream()
@@ -418,6 +431,18 @@ public class ScenarioGridModel extends BaseGridData {
                 .collect(Collectors.toList());
     }
 
+    /**
+     * This methods returns the <code>List&lt;ScenarioGridColumn&gt;</code> of a <b>single</b> block of columns of the same instance/data object.
+     * A <code>single</code> block contains the selected column and all the columns immediately to the left and right of it with the same "label".
+     * If there is another column with the same "label" but separated by a different column, it is not part of the group.
+     * @param selectedColumn
+     * @return
+     */
+    public List<ScenarioGridColumn> getInstanceScenarioGridColumns(ScenarioGridColumn selectedColumn) {
+        int columnIndex = columns.indexOf(selectedColumn);
+        return getInstanceScenarioGridColumns(columnIndex);
+    }
+
     /**
      * Return the first index to the left of the given group, i.e. <b>excluded</b> the left-most index of <b>that</b> group
      * @param groupName
@@ -515,6 +540,46 @@ public class ScenarioGridModel extends BaseGridData {
         selectedColumn = null;
     }
 
+    /**
+     * It forces a <code>internalRefreshWidth</code> refresh
+     */
+    public boolean forceRefreshWidth() {
+        return internalRefreshWidth(true, OptionalDouble.empty());
+    }
+
+    /**
+     * It synchronizes all columns related <code>factMapping</code> columnnWidths
+     */
+    public void synchronizeFactMappingsWidths() {
+        getColumns().forEach(column -> synchronizeFactMappingWidth(column));
+    }
+
+    /**
+     * It updates a column related <code>factMapping</code> columnWidth
+     * @param column
+     */
+    public void synchronizeFactMappingWidth(final GridColumn<?> column) {
+        if (!column.isVisible()) {
+            return;
+        }
+        final int columnIndex = getColumns().indexOf(column);
+        final FactMapping factMapping = simulation.getSimulationDescriptor().getFactMappingByIndex(columnIndex);
+        factMapping.setColumnWidth(column.getWidth());
+    }
+
+    /**
+     * It retrieves the stored columnWidths and assigns them to every grid column.
+     */
+    public void loadFactMappingsWidth() {
+        for (final GridColumn<?> column : getColumns()) {
+            final int columnIndex = getColumns().indexOf(column);
+            final FactMapping factMapping = simulation.getSimulationDescriptor().getFactMappingByIndex(columnIndex);
+            if (factMapping.getColumnWidth() != null) {
+                column.setWidth(factMapping.getColumnWidth());
+            }
+        }
+    }
+
     /**
      * Select all the cells of the given column
      * @param columnIndex
@@ -671,7 +736,7 @@ public class ScenarioGridModel extends BaseGridData {
         return selectedColumn == null || isSameInstanceType(getColumns().indexOf(selectedColumn), className);
     }
 
-     /**
+    /**
      * Check if given <b>headerName</b> is the same as the <b>Fact</b> mapped to the
      * column at given index
      * @param columnIndex
@@ -682,7 +747,6 @@ public class ScenarioGridModel extends BaseGridData {
         if (!isSameInstanceType(columnIndex, headerName)) {
             throw new Exception(headerName + " is not the class of the current column.");
         }
-
     }
 
     /**
