@@ -15,15 +15,27 @@
  */
 package org.drools.workbench.screens.scenariosimulation.client.widgets;
 
+import java.time.LocalDate;
 import java.util.Collections;
 import java.util.List;
+import java.util.Optional;
 import java.util.stream.IntStream;
 
+import com.ait.lienzo.client.core.shape.Layer;
 import com.ait.lienzo.client.core.shape.Viewport;
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import com.google.gwt.event.shared.EventBus;
-import org.drools.workbench.screens.scenariosimulation.client.events.EnableRightPanelEvent;
-import org.drools.workbench.screens.scenariosimulation.client.factories.ScenarioHeaderTextBoxSingletonDOMElementFactory;
+import org.drools.scenariosimulation.api.model.ExpressionElement;
+import org.drools.scenariosimulation.api.model.ExpressionIdentifier;
+import org.drools.scenariosimulation.api.model.FactIdentifier;
+import org.drools.scenariosimulation.api.model.FactMapping;
+import org.drools.scenariosimulation.api.model.FactMappingType;
+import org.drools.scenariosimulation.api.model.Scenario;
+import org.drools.scenariosimulation.api.model.ScenarioSimulationModel;
+import org.drools.scenariosimulation.api.model.Simulation;
+import org.drools.scenariosimulation.api.model.SimulationDescriptor;
+import org.drools.workbench.screens.scenariosimulation.client.events.EnableTestToolsEvent;
+import org.drools.workbench.screens.scenariosimulation.client.events.ReloadTestToolsEvent;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.ScenarioSimulationGridWidgetMouseEventHandler;
 import org.drools.workbench.screens.scenariosimulation.client.menu.ScenarioContextMenuRegistry;
 import org.drools.workbench.screens.scenariosimulation.client.metadata.ScenarioHeaderMetaData;
@@ -31,18 +43,10 @@ import org.drools.workbench.screens.scenariosimulation.client.models.ScenarioGri
 import org.drools.workbench.screens.scenariosimulation.client.renderers.ScenarioGridRenderer;
 import org.drools.workbench.screens.scenariosimulation.client.resources.i18n.ScenarioSimulationEditorConstants;
 import org.drools.workbench.screens.scenariosimulation.client.utils.ScenarioSimulationBuilders;
-import org.drools.workbench.screens.scenariosimulation.model.ExpressionElement;
-import org.drools.workbench.screens.scenariosimulation.model.ExpressionIdentifier;
-import org.drools.workbench.screens.scenariosimulation.model.FactIdentifier;
-import org.drools.workbench.screens.scenariosimulation.model.FactMapping;
-import org.drools.workbench.screens.scenariosimulation.model.FactMappingType;
-import org.drools.workbench.screens.scenariosimulation.model.Scenario;
-import org.drools.workbench.screens.scenariosimulation.model.ScenarioSimulationModel;
-import org.drools.workbench.screens.scenariosimulation.model.Simulation;
-import org.drools.workbench.screens.scenariosimulation.model.SimulationDescriptor;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.mockito.InOrder;
 import org.mockito.Mock;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn.ColumnWidthMode;
@@ -53,13 +57,22 @@ import org.uberfire.ext.wires.core.grids.client.widget.grid.impl.DefaultGridWidg
 import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.grids.impl.BaseGridRendererHelper;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.selections.SelectionExtension;
 
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.COLUMNS;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.EXPRESSION_ALIAS_DESCRIPTION;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.EXPRESSION_ALIAS_GIVEN;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.EXPRESSION_ALIAS_INTEGER;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.GRID_COLUMN_GROUP;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.HEADER_ROWS_HEIGHT;
+import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.TEST;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyInt;
+import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Matchers.isA;
+import static org.mockito.Mockito.inOrder;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.reset;
@@ -78,8 +91,6 @@ public class ScenarioGridTest {
     @Mock
     private ScenarioGridRenderer scenarioGridRendererMock;
     @Mock
-    private ScenarioHeaderTextBoxSingletonDOMElementFactory scenarioHeaderTextBoxSingletonDOMElementFactoryMock;
-    @Mock
     private ScenarioSimulationBuilders.HeaderBuilder headerBuilderMock;
     @Mock
     private ScenarioGridColumn scenarioGridColumnMock;
@@ -100,35 +111,24 @@ public class ScenarioGridTest {
     @Mock
     private ScenarioContextMenuRegistry scenarioContextMenuRegistryMock;
 
-    private final String EXPRESSION_ALIAS_DESCRIPTION = "EXPRESSION_ALIAS_DESCRIPTION";
-    private final String EXPRESSION_ALIAS_GIVEN = "EXPRESSION_ALIAS_GIVEN";
-    private final String EXPRESSION_ALIAS_INTEGER = "EXPRESSION_ALIAS_INTEGER";
-    private final String EXPRESSION_ALIAS_INDEX = "EXPRESSION_ALIAS_INDEX";
-
     private FactMapping factMappingDescription;
-    private FactMapping factMappingIndex;
     private FactMapping factMappingGiven;
     private FactMapping factMappingInteger;
     private FactIdentifier factIdentifierGiven;
     private FactIdentifier factIdentifierInteger;
 
     private Simulation simulation = new Simulation();
-
-    private final int COLUMNS = 6;
-
-    private final double HEADER_ROWS_HEIGHT = 100.0;
-
     private ScenarioGrid scenarioGrid;
 
     @Before
     public void setup() {
         when(scenarioGridColumnMock.getPropertyHeaderMetaData()).thenReturn(propertyHeaderMetadataMock);
+        when(scenarioGridModelMock.getSimulation()).thenReturn(Optional.of(simulation));
         factIdentifierGiven = new FactIdentifier("GIVEN", "GIVEN");
         factIdentifierInteger = new FactIdentifier("Integer", "java.lang.Integer");
         factMappingDescription = new FactMapping(EXPRESSION_ALIAS_DESCRIPTION, FactIdentifier.DESCRIPTION, ExpressionIdentifier.DESCRIPTION);
         factMappingGiven = new FactMapping(EXPRESSION_ALIAS_GIVEN, factIdentifierGiven, new ExpressionIdentifier("GIVEN", FactMappingType.GIVEN));
         factMappingInteger = new FactMapping(EXPRESSION_ALIAS_INTEGER, factIdentifierInteger, new ExpressionIdentifier("GIVEN", FactMappingType.GIVEN));
-        factMappingIndex = new FactMapping(EXPRESSION_ALIAS_INDEX, FactIdentifier.INDEX, ExpressionIdentifier.INDEX);
         simulation = getSimulation();
 
         scenarioGrid = spy(new ScenarioGrid(scenarioGridModelMock,
@@ -161,10 +161,31 @@ public class ScenarioGridTest {
             public Viewport getViewport() {
                 return viewportMock;
             }
+
+            @Override
+            protected ScenarioHeaderMetaData getColumnScenarioHeaderMetaData(final ScenarioGridColumn scenarioGridColumn,
+                                                                             final int rowIndex) {
+                return propertyHeaderMetadataMock;
+            }
+
+            @Override
+            protected EnableTestToolsEvent getEnableTestToolsEvent(final ScenarioGrid scenarioGrid,
+                                                                   final ScenarioGridColumn scenarioGridColumn,
+                                                                   final ScenarioHeaderMetaData scenarioHeaderMetaData,
+                                                                   int uiColumnIndex,
+                                                                   String group) {
+                return new EnableTestToolsEvent();
+            }
+
+            @Override
+            public Layer getLayer() {
+                return scenarioGridLayerMock;
+            }
         });
         when(rendererHelperMock.getRenderingInformation()).thenReturn(renderingInformationMock);
         when(renderingInformationMock.getHeaderRowsHeight()).thenReturn(HEADER_ROWS_HEIGHT);
         when(renderingInformationMock.getFloatingBlockInformation()).thenReturn(floatingBlockInformationMock);
+        when(propertyHeaderMetadataMock.getColumnGroup()).thenReturn(GRID_COLUMN_GROUP);
         scenarioGrid.setEventBus(eventBusMock);
     }
 
@@ -189,11 +210,40 @@ public class ScenarioGridTest {
 
     @Test
     public void setContent() {
+        InOrder callsOrder = inOrder(scenarioGridModelMock, scenarioGrid);
         scenarioGrid.setContent(simulation);
-        verify(scenarioGridModelMock, times(1)).clear();
-        verify(scenarioGridModelMock, times(1)).bindContent(eq(simulation));
-        verify(scenarioGrid, times(1)).setHeaderColumns(eq(simulation));
-        verify(scenarioGrid, times(1)).appendRows(eq(simulation));
+        callsOrder.verify(scenarioGridModelMock, times(1)).clear();
+        callsOrder.verify(scenarioGridModelMock, times(1)).bindContent(eq(simulation));
+        callsOrder.verify(scenarioGrid, times(1)).setHeaderColumns(eq(simulation));
+        callsOrder.verify(scenarioGrid, times(1)).appendRows(eq(simulation));
+        callsOrder.verify(scenarioGridModelMock, times(1)).loadFactMappingsWidth();
+        callsOrder.verify(scenarioGridModelMock, times(1)).forceRefreshWidth();
+    }
+
+    @Test
+    public void clearSelections() {
+        scenarioGrid.clearSelections();
+        verify(scenarioGridModelMock, times(1)).clearSelections();
+        verify(scenarioGridLayerMock, times(1)).batch();
+    }
+
+    @Test
+    public void setSelectedColumnAndHeader() {
+        int headerRowIndex = 1;
+        int columnIndex = 1;
+        scenarioGrid.setSelectedColumnAndHeader(headerRowIndex, columnIndex);
+        verify(scenarioGridModelMock, times(1)).selectColumn(eq(columnIndex));
+        verify(scenarioGridModelMock, times(1)).selectHeaderCell(eq(headerRowIndex), eq(columnIndex));
+        verify(scenarioGridLayerMock, times(1)).batch();
+    }
+
+    @Test
+    public void setSelectedCell() {
+        int rowIndex = 1;
+        int columnIndex = 1;
+        scenarioGrid.setSelectedCell(rowIndex, columnIndex);
+        verify(scenarioGrid, times(1)).selectCell(eq(rowIndex), eq(columnIndex), eq(false), eq(false));
+        verify(scenarioGridLayerMock, times(1)).batch();
     }
 
     @Test
@@ -209,13 +259,13 @@ public class ScenarioGridTest {
         String columnGroup = type.name();
         scenarioGrid.setHeaderColumn(1, factMappingDescription, true);
         verify(scenarioGrid, times(1)).isPropertyAssigned(eq(true), eq(factMappingDescription));
-        verify(scenarioGrid, times(1)).getPlaceholder(eq(true));
+        verify(scenarioGrid, times(1)).getPlaceholder(eq(true), any());
         verify(scenarioGrid, times(1)).getScenarioGridColumnLocal(eq(EXPRESSION_ALIAS_DESCRIPTION),
                                                                   any(),
                                                                   eq(columnId),
                                                                   eq(columnGroup),
                                                                   eq(type),
-                                                                  eq(ScenarioSimulationEditorConstants.INSTANCE.insertValue()));
+                                                                  anyString());
         verify(scenarioGridColumnMock, times(1)).setColumnWidthMode(ColumnWidthMode.FIXED);
 
         reset(scenarioGrid);
@@ -226,13 +276,13 @@ public class ScenarioGridTest {
         columnGroup = type.name();
         scenarioGrid.setHeaderColumn(1, factMappingGiven, true);
         verify(scenarioGrid, times(1)).isPropertyAssigned(eq(true), eq(factMappingGiven));
-        verify(scenarioGrid, times(1)).getPlaceholder(eq(false));
+        verify(scenarioGrid, times(1)).getPlaceholder(eq(false), any());
         verify(scenarioGrid, times(1)).getScenarioGridColumnLocal(eq(EXPRESSION_ALIAS_GIVEN),
                                                                   any(),
                                                                   eq(columnId),
                                                                   eq(columnGroup),
                                                                   eq(type),
-                                                                  eq(ScenarioSimulationEditorConstants.INSTANCE.defineValidType()));
+                                                                  anyString());
         verify(scenarioGridColumnMock, never()).setColumnWidthMode(any());
     }
 
@@ -264,7 +314,7 @@ public class ScenarioGridTest {
         factMappingDescription.getExpressionElements().clear();
         assertTrue(scenarioGrid.isPropertyAssigned(false, factMappingDescription));
         assertTrue(scenarioGrid.isPropertyAssigned(true, factMappingDescription));
-        factMappingDescription.getExpressionElements().add(new ExpressionElement("test"));
+        factMappingDescription.getExpressionElements().add(new ExpressionElement(TEST));
         assertTrue(scenarioGrid.isPropertyAssigned(false, factMappingDescription));
         assertTrue(scenarioGrid.isPropertyAssigned(true, factMappingDescription));
         factMappingGiven.getExpressionElements().clear();
@@ -280,8 +330,21 @@ public class ScenarioGridTest {
 
     @Test
     public void getPlaceholder() {
-        assertEquals(ScenarioSimulationEditorConstants.INSTANCE.insertValue(), scenarioGrid.getPlaceholder(true));
-        assertEquals(ScenarioSimulationEditorConstants.INSTANCE.defineValidType(), scenarioGrid.getPlaceholder(false));
+        FactMapping stringFactMapping = new FactMapping(
+                FactIdentifier.create("test", String.class.getCanonicalName()),
+                ExpressionIdentifier.create("test", FactMappingType.GIVEN));
+        assertEquals(ScenarioSimulationEditorConstants.INSTANCE.insertValue(),
+                     scenarioGrid.getPlaceholder(true, stringFactMapping));
+        assertEquals(ScenarioSimulationEditorConstants.INSTANCE.defineValidType(),
+                     scenarioGrid.getPlaceholder(false, stringFactMapping));
+
+        FactMapping localDateFactMapping = new FactMapping(
+                FactIdentifier.create("test", LocalDate.class.getCanonicalName()),
+                ExpressionIdentifier.create("test", FactMappingType.GIVEN));
+        assertEquals(ScenarioSimulationEditorConstants.INSTANCE.dateFormatPlaceholder(),
+                     scenarioGrid.getPlaceholder(true, localDateFactMapping));
+        assertEquals(ScenarioSimulationEditorConstants.INSTANCE.defineValidType(),
+                     scenarioGrid.getPlaceholder(false, localDateFactMapping));
     }
 
     @Test
@@ -305,12 +368,13 @@ public class ScenarioGridTest {
 
         scenarioGrid.adjustSelection(mock(SelectionExtension.class), false);
 
-        verify(scenarioGrid).signalRightPanelAboutSelectedHeaderCells();
+        verify(scenarioGrid).signalTestTools();
         verify(scenarioGrid).setSelectedColumnAndHeader(uiRowIndex, uiColumnIndex);
-        verify(eventBusMock).fireEvent(any(EnableRightPanelEvent.class));
+        verify(eventBusMock).fireEvent(any(EnableTestToolsEvent.class));
 
         // context menus could be shown
-        verify(scenarioContextMenuRegistryMock).hideMenus();
+        verify(scenarioContextMenuRegistryMock, times(1)).hideMenus();
+        verify(scenarioContextMenuRegistryMock, times(1)).hideErrorReportPopover();
     }
 
     @Test
@@ -388,4 +452,38 @@ public class ScenarioGridTest {
         });
         return toReturn;
     }
+
+    @Test
+    public void signalTestToolsHeaderCellSelected() {
+        final int uiColumnIndex = 0;
+        final int uiRowIndex = 0;
+        final ScenarioGridColumn columnMock = mock(ScenarioGridColumn.class);
+        when(columnMock.getIndex()).thenReturn(uiColumnIndex);
+        when(scenarioGridModelMock.getColumns()).thenReturn(Collections.singletonList(columnMock));
+
+        final GridData.SelectedCell selectedHeaderCell = mock(GridData.SelectedCell.class);
+        when(selectedHeaderCell.getColumnIndex()).thenReturn(uiColumnIndex);
+        when(selectedHeaderCell.getRowIndex()).thenReturn(uiRowIndex);
+        when(scenarioGridModelMock.getSelectedHeaderCells()).thenReturn(Collections.singletonList(selectedHeaderCell));
+        scenarioGrid.signalTestToolsHeaderCellSelected(columnMock, selectedHeaderCell, uiColumnIndex);
+        verify(eventBusMock, times(1)).fireEvent(isA(EnableTestToolsEvent.class));
+    }
+
+    @Test
+    public void signalTestToolsHeaderCellSelected_EmptyInstance() {
+        final int uiColumnIndex = 0;
+        final int uiRowIndex = 0;
+        final ScenarioGridColumn columnMock = mock(ScenarioGridColumn.class);
+        when(columnMock.getIndex()).thenReturn(uiColumnIndex);
+        when(scenarioGridModelMock.getColumns()).thenReturn(Collections.singletonList(columnMock));
+        when(columnMock.isInstanceAssigned()).thenReturn(true);
+        when(propertyHeaderMetadataMock.getMetadataType()).thenReturn(ScenarioHeaderMetaData.MetadataType.INSTANCE);
+
+        final GridData.SelectedCell selectedHeaderCell = mock(GridData.SelectedCell.class);
+        when(selectedHeaderCell.getColumnIndex()).thenReturn(uiColumnIndex);
+        when(selectedHeaderCell.getRowIndex()).thenReturn(uiRowIndex);
+        when(scenarioGridModelMock.getSelectedHeaderCells()).thenReturn(Collections.singletonList(selectedHeaderCell));
+        scenarioGrid.signalTestToolsHeaderCellSelected(columnMock, selectedHeaderCell, uiColumnIndex);
+        verify(eventBusMock, times(1)).fireEvent(isA(ReloadTestToolsEvent.class));
+    }
 }
\ No newline at end of file
